Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1292)

Unified Diff: runtime/bin/gen_snapshot.cc

Issue 1127343004: Reland r45669: (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/dartutils.cc ('k') | runtime/bin/vmservice/loader.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/bin/gen_snapshot.cc
===================================================================
--- runtime/bin/gen_snapshot.cc (revision 45696)
+++ runtime/bin/gen_snapshot.cc (working copy)
@@ -196,19 +196,20 @@
Dart_Isolate UriResolverIsolateScope::isolate = NULL;
-static Dart_Handle ResolveScriptUri(const char* script_uri) {
+static Dart_Handle ResolveUriInWorkingDirectory(const char* script_uri) {
bool failed = false;
char* result_string = NULL;
{
UriResolverIsolateScope scope;
// Run DartUtils::ResolveScriptUri in context of uri resolver isolate.
Dart_Handle builtin_lib =
Builtin::LoadAndCheckLibrary(Builtin::kBuiltinLibrary);
CHECK_RESULT(builtin_lib);
- Dart_Handle result = DartUtils::ResolveScriptUri(
+ Dart_Handle result = DartUtils::ResolveUriInWorkingDirectory(
DartUtils::NewString(script_uri), builtin_lib);
if (Dart_IsError(result)) {
failed = true;
@@ -310,7 +311,7 @@
const char* mapped_library_url_string = DartUtils::MapLibraryUrl(
url_mapping, library_url_string);
if (mapped_library_url_string != NULL) {
- library_url = ResolveScriptUri(mapped_library_url_string);
+ library_url = ResolveUriInWorkingDirectory(mapped_library_url_string);
library_url_string = DartUtils::GetStringValue(library_url);
}
@@ -356,7 +357,7 @@
Dart_Handle resolved_url = url;
if (mapped_url_string != NULL) {
// Mapped urls are relative to working directory.
- resolved_url = ResolveScriptUri(mapped_url_string);
+ resolved_url = ResolveUriInWorkingDirectory(mapped_url_string);
if (Dart_IsError(resolved_url)) {
return resolved_url;
}
@@ -383,7 +384,7 @@
static Dart_Handle LoadSnapshotCreationScript(const char* script_name) {
- Dart_Handle resolved_script_uri = ResolveScriptUri(script_name);
+ Dart_Handle resolved_script_uri = ResolveUriInWorkingDirectory(script_name);
if (Dart_IsError(resolved_script_uri)) {
return resolved_script_uri;
}
@@ -196,19 +196,20 @@
{
UriResolverIsolateScope scope;
- // Run DartUtils::ResolveScriptUri in context of uri resolver isolate.
+ // Run DartUtils::ResolveUriInWorkingDirectory in context of uri resolver
+ // isolate.
Dart_Handle builtin_lib =
Builtin::LoadAndCheckLibrary(Builtin::kBuiltinLibrary);
« no previous file with comments | « runtime/bin/dartutils.cc ('k') | runtime/bin/vmservice/loader.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698